//! Data Types and functions related to colors and images.

pub use color::Color;
pub use texture::Texture;

// Use `self` to avoid name conflict with the `image` crate.
pub use self::image::Image;
pub use self::image::ImageTile;

mod color;
mod image;
mod texture;
